==> opensearch-java-2.6.0-sources.jar: org/opensearch/client/opensearch/core/search/ContextBuilders.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package org.opensearch.client.opensearch.core.search;

import org.opensearch.client.opensearch._types.GeoLocation;

/**
 * Builders for {@link Context} variants.
 * <p>
 * Variants <code>category</code> are not available here as they don't have a
 * dedicated class. Use {@link Context}'s builder for these.
 * 
 */
public class ContextBuilders {
	private ContextBuilders() {
	}

	/**
	 * Creates a builder for the {@link GeoLocation location} {@code Context}
	 * variant.
	 */
	public static GeoLocation.Builder location() {
		return new GeoLocation.Builder();
	}

}

==> opensearch-java-2.24.0-sources.jar: org/opensearch/client/opensearch/core/search/ContextBuilders.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

package org.opensearch.client.opensearch.core.search;

import org.opensearch.client.opensearch._types.GeoLocation;

/**
 * Builders for {@link Context} variants.
 * <p>
 * Variants <code>category</code> are not available here as they don't have a
 * dedicated class. Use {@link Context}'s builder for these.
 *
 */
public class ContextBuilders {
    private ContextBuilders() {}

    /**
     * Creates a builder for the {@link GeoLocation location} {@code Context}
     * variant.
     */
    public static GeoLocation.Builder location() {
        return new GeoLocation.Builder();
    }

}
